"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getServerSession = getServerSession;
exports.default = void 0;

var _core = require("../core");

var _extendRes = _interopRequireDefault(require("../core/lib/extend-res"));

var _cookie = require("../core/lib/cookie");

var _logger = _interopRequireWildcard(require("../lib/logger"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

async function NextAuthNextHandler(req, res, options) {
  (0, _extendRes.default)(req, res);
  const {
    nextauth,
    action = nextauth[0],
    providerId = nextauth[1],
    error = nextauth[1]
  } = req.query;

  if (options.logger) {
    (0, _logger.setLogger)(options.logger);
  }

  if (!req.query.nextauth) {
    const message = "Cannot find [...nextauth].js in pages/api/auth. Make sure the filename is written correctly.";

    _logger.default.error("MISSING_NEXTAUTH_API_ROUTE_ERROR", new Error(message));

    return {
      status: 500,
      text: `Error: ${message}`
    };
  }

  const request = {
    body: req.body,
    query: req.query,
    cookies: req.cookies,
    headers: req.headers,
    method: req.method,
    action,
    providerId,
    error
  };
  const {
    json,
    redirect,
    text,
    cookies,
    headers,
    status = 200
  } = await (0, _core.NextAuthHandler)({
    req: request,
    options
  });
  res.status(status);
  cookies === null || cookies === void 0 ? void 0 : cookies.forEach(cookie => {
    (0, _cookie.set)(res, cookie.name, cookie.value, cookie.options);
  });
  headers === null || headers === void 0 ? void 0 : headers.forEach(header => {
    res.setHeader(header.key, header.value);
  });

  if (redirect) {
    return res.redirect(redirect);
  } else if (json) {
    return res.json(json);
  } else if (text) {
    return res.send(text);
  }

  return res.status(400).send(`Error: HTTP ${req.method} is not supported for ${req.url}`);
}

function NextAuth(...args) {
  if (args.length === 1) {
    return async (req, res) => await NextAuthNextHandler(req, res, args[0]);
  }

  return NextAuthNextHandler(args[0], args[1], args[2]);
}

var _default = NextAuth;
exports.default = _default;

async function getServerSession(context, options) {
  const session = await (0, _core.NextAuthHandler)({
    options,
    req: {
      action: "session",
      method: "GET",
      cookies: context.req.cookies,
      headers: context.req.headers
    }
  });
  const {
    json,
    cookies
  } = session;
  cookies === null || cookies === void 0 ? void 0 : cookies.forEach(cookie => {
    (0, _cookie.set)(context.res, cookie.name, cookie.value, cookie.options);
  });
  if (!json) return null;
  return Object.keys(json) ? json : null;
}